pygeodesy.hausdorff.HausdorffCosineLaw

Package pygeodesy :: Module hausdorff :: Class HausdorffCosineLaw |
[frames] | no frames]

# Class HausdorffCosineLaw

        object --+
                 |
      named._Named --+
                     |
             Hausdorff --+
                         |
    _HausdorffMeterRadians --+
                             |
                            HausdorffCosineLaw

Compute the `Hausdorff` distance with function pygeodesy.cosineLaw_.

Note: See note at function pygeodesy.vincentys_.

Instance Methods
__init__(self, point1s, **seed_name__corr_earth_wrap) New HausdorffCosineLaw calculator. |
directed(self, point2s, early=True) Compute only the `forward Hausdorff` distance. |
symmetric(self, point2s, early=True) Compute the combined `forward and reverse Hausdorff` distance. |
Inherited from `Hausdorff`: `distance`, `point` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Hausdorff`: `adjust`, `datum`, `kwds`, `seed`, `units`, `wrap` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, point1s, **seed_name__corr_earth_wrap) (Constructor) |
New HausdorffCosineLaw calculator. Arguments: `seed_name__corr_earth_wrap` - Optional `seed=None` and `name=NN` and keyword arguments for function pygeodesy.cosineLaw. Raises: `HausdorffError` - Insufficient number of `point1s` or an invalid `point1`, `seed` or `units`. Overrides: object.__init__ See Also: Hausdorff.__init__ for details about `point1s`, `seed`, `name` and other exceptions.

### directed (self, point2s, early=True) |
Compute only the `forward Hausdorff` distance. Arguments: `point2s` - Second set of points, aka the `target` (`LatLon`[], `Numpy2LatLon`[], `Tuple2LatLon`[] or `other`[]). `early` - Enable or disable early breaking (`bool`). Returns: A Hausdorff6Tuple`(hd, i, j, mn, md, units)`. Raises: `HausdorffError` - Insufficient number of `point2s` or an invalid `point2`. Overrides: Hausdorff.directed Note: See `point2s` note at HausdorffDistanceTo.

### symmetric (self, point2s, early=True) |
Compute the combined `forward and reverse Hausdorff` distance. Arguments: `point2s` - Second set of points, aka the `target` (`LatLon`[], `Numpy2LatLon`[], `Tuple2LatLon`[] or `other`[]). `early` - Enable or disable early breaking (`bool`). Returns: A Hausdorff6Tuple`(hd, i, j, mn, md, units)`. Raises: `HausdorffError` - Insufficient number of `point2s` or an invalid `point2`. Overrides: Hausdorff.symmetric Note: See `point2s` note at HausdorffDistanceTo.